#Mantel test 
library(vegan)
install.packages("geosphere")
library(geosphere)

library(readxl)
setwd("E:/Thesis C.elegans May 2020/Excel data sheet/Mantel test")
dat = read_excel("R and D RF2018 with R software.xlsx", 
                  sheet = "Sheet1")

dat$Dm = dat$Dcm/100
View(dat)


#Relatedness vector
relat = dat$R

#Distance vector 
dist1 = dat$Dm

#relatedness vector - euclidean distance
dist.relat = dist(relat, method = "euclidean")
#relatedness vector - euclidean distance
dist.dist1 = dist(dist1, method = "euclidean")

#Mantel command
relat_dist1 = mantel(dist.relat, dist.dist1, method = "spearman", permutations = 9999, na.rm = TRUE)

relat_dist1

#Mantel statistic based on Spearman's rank correlation rho 

#Call:
 # mantel(xdis = dist.relat, ydis = dist.dist1, method = "spearman",      permutations = 9999, na.rm = TRUE) 

#Mantel statistic r: -0.01171 
#Significance: 0.6394 
#Upper quantiles of permutations (null model):
#  90%    95%  97.5%    99% 
#  0.0382 0.0507 0.0614 0.0741 
#Permutation: free
#Number of permutations: 9999

plot(dat$Dm,  dat$R,
     ylab="Relatedness", xlab="Distance (m)",
     main = "Correlation:
    Relatedness and distance between colonies") 


#scatter plot 
library(ggplot2)


mm = ggplot(dat, aes(y = R, x = Dm)) + 
  geom_point(size = 3, alpha = 0.5, colour="black") + 
  annotate("text", min(dat$Dm), 0.9, vjust = +1, label = "l      Full-sister", colour="red") +
  labs(title="", x = "Distance (m)", y = "Relatedness") +
  theme( axis.text.x = element_text(face = "bold",colour = "black", size = 10), 
         axis.text.y = element_text(face = "bold", size = 10, colour = "black"), 
         axis.title= element_text(face = "bold", size = 13, colour = "black"), 
         panel.background = element_blank(), 
         panel.border = element_rect(fill = NA, colour = "black"))



mm+ ylim(-1, 1) + geom_hline(yintercept=0.75, linetype="dashed", color = "red", size=1, show.legend=TRUE) 

#linetype="dotdash", "solid", "dashed", "dotted", "blank", "twodash", "longdash"


library(svglite)

?ggsave()
ggsave("Rplot.svg")

#linear regression test
lm = lm(dat$R~dat$Dcm)
summary(lm)
#no linear regression


#too dark dots
xx = ggplot(dat, aes(x = Dcm, y = R)) + 
  geom_smooth(method = "lm", alpha = 0.2, colour = "blue") + 
  geom_point(size = 3) + 
  labs(y = "Relatedness", x = "Distance (cm)") + 
  theme( axis.text.x = element_text(face = "bold",colour = "black", size = 12), 
         axis.text.y = element_text(face = "bold", size = 11, colour = "black"), 
         axis.title= element_text(face = "bold", size = 14, colour = "black"), 
         panel.background = element_blank(), 
         panel.border = element_rect(fill = NA, colour = "black"))

xx 